<?php

namespace Drupal\admin_domain\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure admin domain settings.
 */
class AdminDomainSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'admin_domain_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'admin_domain.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $field_type = NULL) {
    $config = $this->config('admin_domain.settings');

    $form['domains'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Domains'),
      '#open' => TRUE,
    ];

    $form['domains']['public_domain'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Public domain'),
      '#default_value' => $config->get('public_domain'),
      '#description' => $this->t('The domain to use for all public-facing routes (views, node displays, forms, etc).'),
      '#required' => TRUE,
    ];

    $form['domains']['protected_domain'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Protected domain'),
      '#default_value' => $config->get('protected_domain'),
      '#description' => $this->t('The domain to use for all admin and management routes (edit, delete, configuration, etc).'),
      '#required' => TRUE,
    ];

    $form['routing'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Routing'),
      '#open' => TRUE,
    ];

    $form['routing']['admin_routes'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Automatically include admin routes'),
      '#default_value' => $config->get('admin_routes'),
      '#description' => $this->t('Check this box to automatically include all routes marked with "_admin_route" equal to "TRUE".'),
      '#default_value' => $config->get('admin_routes'),
    ];

    $form['routing']['protected_routes'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Protected routes'),
      '#default_value' => $config->get('protected_routes'),
      '#description' => $this->t('Enter any routes, one per line, that should be routed to the protected domain instead of the public-facing domain. Use an asterisk (*) at the end of your routes for wildcard matching.'),
    ];

    $form['routing']['protected_paths'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Protected domain'),
      '#default_value' => $config->get('protected_paths'),
      '#description' => $this->t('Enter any url paths, one per line, that should be routed to the protected domain instead of the public-facing domain. Use an asterisk (*) at the end of your paths for wildcard matching.'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('admin_domain.settings');

    $keys = array(
      'public_domain',
      'protected_domain',
      'admin_routes',
      'protected_routes',
      'protected_paths',
    );
    foreach ($keys as $key) {
      $config->set($key, $form_state->getValue($key));
    }
    $config->save();

    parent::submitForm($form, $form_state);
  }

}
